| check_required_packages | R Documentation |
Verifies that necessary packages are installed for the specified model type. Stops with informative error if required packages are missing.
check_required_packages(model_type)
model_type |
Character string indicating model type. |
NULL (invisibly). Stops execution if packages missing.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.