format_column_headers_html: Apply formatting to column headers in exported tables (HTML)

format_column_headers_htmlR Documentation

Apply formatting to column headers in exported tables (HTML)

Description

Formats column headers for HTML output by italicizing 'n' and 'p' using HTML tags.

Usage

format_column_headers_html(col_names)

Arguments

col_names

Character vector of column names.

Value

Character vector with HTML-formatted column names.


summata documentation built on May 7, 2026, 5:07 p.m.