format_headers_ft: Format headers for flextable

View source: R/table2_utils.R

format_headers_ftR Documentation

Format headers for flextable

Description

Applies formatting to flextable headers including italicizing 'n', adding sample size counts from N row data, and bolding all headers.

Usage

format_headers_ft(ft, has_n_row, n_row_data)

Arguments

ft

flextable object.

has_n_row

Logical whether source data had an N row.

n_row_data

Data from the N row for adding counts to headers.

Value

Formatted flextable object.


summata documentation built on May 7, 2026, 5:07 p.m.