| calculate_model_scores | R Documentation |
Computes composite Score based on weighted combination of model quality metrics. Weights vary by model type to reflect academic consensus on important metrics for each model class.
calculate_model_scores(comparison, model_type, scoring_weights = NULL)
comparison |
Data.table with model comparison metrics. |
model_type |
Character string indicating model type. |
scoring_weights |
Optional named list of custom weights. If |
Data.table with CMS column added, sorted by score.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.