| finalize_column_names | R Documentation |
Renames internal column names (uni_effect, uni_p, multi_effect, multi_p) to publication-ready display names with appropriate effect measure labels (OR, HR, RR, aOR, aHR, aRR, Coefficient, etc.).
finalize_column_names(
result,
uni_raw,
multi_raw,
exponentiate,
columns,
metrics,
conf_level = 0.95
)
result |
Data.table with columns to rename. Expected to contain some combination of: uni_effect, uni_p, multi_effect, multi_p. |
uni_raw |
Raw univariable data.table used to determine effect type by checking for presence of OR, HR, RR, or Coefficient columns. |
multi_raw |
Raw multivariable data.table used to determine adjusted effect type. |
exponentiate |
Logical or |
columns |
Character string indicating which columns are present
( |
metrics |
Character vector of metrics being displayed ( |
The input data.table with columns renamed
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.