| format_headers_ft | R Documentation |
Applies formatting to flextable headers including italicizing 'n', adding sample size counts from N row data, and bolding all headers.
format_headers_ft(ft, has_n_row, n_row_data)
ft |
flextable object. |
has_n_row |
Logical whether source data had an N row. |
n_row_data |
Data from the N row for adding counts to headers. |
Formatted flextable object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.