| get_cached_confint | R Documentation |
Returns confidence intervals for a fitted model, using a cached result
when available from upstream fit() or m2dt() calls to avoid
redundant computation. This is particularly beneficial for GLM and negative
binomial models where confint() performs profile likelihood profiling,
which can be expensive for models with many parameters.
get_cached_confint(model, conf_level = 0.95)
model |
Fitted model object. If the model carries a
|
conf_level |
Numeric confidence level. Must match the cached level for the cache to be used. |
A matrix with one row per model coefficient and two columns
(lower and upper bounds), as returned by stats::confint().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.