| identify_variable_groups | R Documentation |
Detects variable group boundaries by finding rows where Variable column is non-empty. Returns row indices for each group for zebra stripe application.
identify_variable_groups(df)
df |
Data.table with Variable column. |
List of integer vectors, each containing row indices for one variable group.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.