| print.fullfit_result | R Documentation |
Displays a summary header with outcome, model type, method, and number of multivariable predictors before printing the results table.
## S3 method for class 'fullfit_result'
print(x, ...)
x |
fullfit_result object. |
... |
Additional arguments passed to print methods. |
Invisibly returns the input object x. Called for its
side effect of printing a formatted summary to the console.
Other regression functions:
compfit(),
fit(),
fullfit(),
multifit(),
print.compfit_result(),
print.fit_result(),
print.multifit_result(),
print.uniscreen_result(),
uniscreen()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.