| reorder_total_column | R Documentation |
Rearranges data.table columns to place the total column in the specified position (first, last, or default). Ensures proper ordering of Variable, Group, total, group columns, and p-value.
reorder_total_column(result, total, total_label)
result |
Data.table with columns to reorder. |
total |
Logical or character: |
total_label |
Character string name of the total column. |
Modified data.table with reordered columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.