| validate_outcome_homogeneity | R Documentation |
Checks whether all outcomes in a multifit analysis are compatible with the specified model type. Issues a warning when outcomes appear to be of mixed types (e.g., binary and continuous outcomes in the same analysis), which would produce tables with incompatible effect measures.
validate_outcome_homogeneity(data, outcomes, model_type, family = "binomial")
data |
Data.table containing the analysis data. |
outcomes |
Character vector of outcome variable names. |
model_type |
Character string specifying the model type. |
family |
Character string specifying the GLM family (for glm/glmer). |
Invisible NULL. Issues warnings if problems are detected.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.